@@ -31,7 +31,7 @@ int main(int argc, char **argv)
     tok = strtok(argv[1],argv[2]);
     while(tok)
     {
-        printf("%s",tok);
+        printf("\"%s\"",tok);
         tok = strtok(NULL,argv[2]);
         if(tok) printf(" ");
     }
